# Changelog

## 0.1.0-alpha.1 (2025-02-27)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/descarteslabs/hedgewise-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([c8c2924](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c8c2924cf05e94aba74193e386db90e208f68bd4))


### Chores

* go live ([#1](https://github.com/descarteslabs/hedgewise-sdk-python/issues/1)) ([7db5a4b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7db5a4b0721e7babbdc14ee3a58ba35c1f64d15f))
* update SDK settings ([#3](https://github.com/descarteslabs/hedgewise-sdk-python/issues/3)) ([0d26126](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0d261266fb96264bf4ca9910ee793316fcb5c3f3))
